@@ -3,14 +3,14 @@ package Firefox::Marionette::Certificate;
 use strict;
 use warnings;
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub _NUMBER_OF_MICROSECOND_DIGITS { return -6 }
 
 sub new {
-    my ( $class, $parameters ) = @_;
+    my ( $class, %parameters ) = @_;
 
-    my $self = bless { %{$parameters} }, $class;
+    my $self = bless { %parameters }, $class;
     return $self;
 }
 
@@ -26,18 +26,20 @@ sub common_name {
 
 sub _cert_type {
     my ($self) = @_;
-    if ( defined $self->{certType} ) {
-        return $self->{certType};
+    return $self->{certType};
+}
+
+sub _bitwise_and_with_cert_type {
+    my ( $self, $argument ) = @_;
+    if ( defined $self->_cert_type() ) {
+        return $argument & $self->_cert_type();
     }
-    return 0;
+    return;
 }
 
 sub is_any_cert {
     my ($self) = @_;
-    if ( defined $self->{ANY_CERT} ) {
-        return $self->{ANY_CERT} & $self->_cert_type();
-    }
-    return 0;
+    return $self->_bitwise_and_with_cert_type( $self->{ANY_CERT} );
 }
 
 sub email_address {
@@ -64,7 +66,7 @@ sub db_key {
 
 sub is_unknown_cert {
     my ($self) = @_;
-    return $self->{UNKNOWN_CERT} & $self->_cert_type();
+    return $self->_bitwise_and_with_cert_type( $self->{UNKNOWN_CERT} );
 }
 
 sub is_built_in_root {
@@ -84,12 +86,12 @@ sub sha256_fingerprint {
 
 sub is_server_cert {
     my ($self) = @_;
-    return $self->{SERVER_CERT} & $self->_cert_type();
+    return $self->_bitwise_and_with_cert_type( $self->{SERVER_CERT} );
 }
 
 sub is_user_cert {
     my ($self) = @_;
-    return $self->{USER_CERT} & $self->_cert_type();
+    return $self->_bitwise_and_with_cert_type( $self->{USER_CERT} );
 }
 
 sub subject_name {
@@ -104,7 +106,7 @@ sub key_usages {
 
 sub is_ca_cert {
     my ($self) = @_;
-    return $self->{CA_CERT} & $self->_cert_type();
+    return $self->_bitwise_and_with_cert_type( $self->{CA_CERT} );
 }
 
 sub issuer_organization_unit {
@@ -135,7 +137,7 @@ sub serial_number {
 
 sub is_email_cert {
     my ($self) = @_;
-    return $self->{EMAIL_CERT} & $self->_cert_type();
+    return $self->_bitwise_and_with_cert_type( $self->{EMAIL_CERT} );
 }
 
 sub issuer_common_name {
@@ -177,7 +179,7 @@ Firefox::Marionette::Certificate - Represents a x509 Certificate from Firefox
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -204,7 +206,7 @@ returns the common name from the certificate.  This can contain the domain name
 
 =head2 db_key
 
-returns a unique value for the certificate, such as 'AAAAAAAAAAAAAAAQAAAAzS+A/iOMDiIPSGcSKJGHrLMwgcoxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5jLjEfMB0GA1UECxMWVmVyaVNpZ24gVHJ1c3QgTmV0d29yazE6MDgGA1UECxMxKGMpIDIwMDcgVmVyaVNpZ24sIEluYy4gLSBGb3IgYXV0aG9yaXplZCB1c2Ugb25seTFFMEMGA1UEAxM8VmVyaVNpZ24gQ2xhc3MgMyBQdWJsaWMgUHJpbWFyeSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eSAtIEc0'
+returns a unique value for the certificate.  This looks like a Base64 encoded string approximately 316 bytes long when encoded.
 
 =head2 display_name
 
@@ -336,7 +338,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
