@@ -2,8 +2,9 @@ package Firefox::Marionette::Element;
 
 use strict;
 use warnings;
+use parent qw(Firefox::Marionette::LocalObject);
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub IDENTIFIER { return 'element-6066-11e4-a52e-4f735466cecf' }
 
@@ -16,33 +17,17 @@ sub new {
     else {
         delete $parameters{ELEMENT};
     }
-    my $element = bless {
-        browser => $browser,
-        %parameters
-    }, $class;
-    return $element;
+    return $class->SUPER::new( $browser, %parameters );
 }
 
-sub TO_JSON {
+sub aria_label {
     my ($self) = @_;
-    my $json = {};
-    if ( $self->{_old_protocols_key} ) {
-        $json->{ $self->{_old_protocols_key} } = $self->uuid();
-    }
-    else {
-        $json->{ IDENTIFIER() } = $self->uuid();
-    }
-    return $json;
+    return $self->browser()->aria_label($self);
 }
 
-sub uuid {
+sub aria_role {
     my ($self) = @_;
-    return $self->{ IDENTIFIER() };
-}
-
-sub browser {
-    my ($self) = @_;
-    return $self->{browser};
+    return $self->browser()->aria_role($self);
 }
 
 sub click {
@@ -56,8 +41,8 @@ sub clear {
 }
 
 sub scroll {
-    my ($self) = @_;
-    return $self->browser()->scroll($self);
+    my ( $self, $arguments ) = @_;
+    return $self->browser()->scroll( $self, $arguments );
 }
 
 sub text {
@@ -350,7 +335,7 @@ Firefox::Marionette::Element - Represents a Firefox element retrieved using the
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -367,16 +352,26 @@ Version 1.35
 
 This module handles the implementation of a Firefox Element using the Marionette protocol
 
+=head1 CONSTANTS
+
+=head2 IDENTIFIER
+
+returns the L<web element identifier|https://www.w3.org/TR/webdriver/#elements>
+
 =head1 SUBROUTINES/METHODS
 
+=head2 aria_label
+
+returns the L<ARIA label|https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Attributes/aria-label> for the L<element|Firefox::Marionette::Element>.
+
+=head2 aria_role
+
+returns the L<ARIA role|https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles> for the L<element|Firefox::Marionette::Element>.
+
 =head2 attribute 
 
 accepts a scalar name a parameter.  It returns the initial value of the attribute with the supplied name. Compare with the current value returned by L<property|Firefox::Marionette::Element#property> method.
 
-=head2 browser
-
-returns the L<browser|Firefox::Marionette> connected with the L<element|Firefox::Marionette::Element>.
-
 =head2 clear
 
 clears any user supplied input from the L<element|Firefox::Marionette::Element>
@@ -719,10 +714,6 @@ This method is subject to the L<implicit|Firefox::Marionette::Timeouts#implicit>
 
 If no elements are found, this method will return undef.  For the same functionality that throws a L<not found|Firefox::Marionette::Exception::NotFound> exception, see the L<find_partial|Firefox::Marionette::Element#find_partial> method.
 
-=head2 IDENTIFIER
-
-returns the L<web element identifier|https://www.w3.org/TR/webdriver/#elements>
-
 =head2 is_enabled
 
 returns true or false if the element is enabled.
@@ -858,7 +849,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
