@@ -5,7 +5,7 @@ use warnings;
 use Carp();
 use overload '""' => 'string';
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub throw {
     my ( $class, $string ) = @_;
@@ -27,7 +27,11 @@ sub _throw {
 
 sub string {
     my ($self) = @_;
-    return $self->{string} . qq[\n];
+    return
+        $self->{string} . q[ at ]
+      . $self->{origin}
+      . q[ line ]
+      . $self->{line} . qq[\n];
 }
 
 1;    # Magic true value required at end of module
@@ -39,7 +43,7 @@ Firefox::Marionette::Exception - Represents an base exception class for exceptio
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -86,7 +90,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
