@@ -2,9 +2,9 @@ package Firefox::Marionette::Exception::Response;
 
 use strict;
 use warnings;
-use base qw(Firefox::Marionette::Exception);
+use parent qw(Firefox::Marionette::Exception);
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub throw {
     my ( $class, $response ) = @_;
@@ -45,7 +45,7 @@ Firefox::Marionette::Exception::Response - Represents an exception thrown by Fir
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
