@@ -2,23 +2,14 @@ package Firefox::Marionette::Exception::StaleElement;
 
 use strict;
 use warnings;
-use base qw(Firefox::Marionette::Exception::Response);
+use parent qw(Firefox::Marionette::Exception::Response);
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub throw {
     my ( $class, $response, $parameters ) = @_;
-    my $string;
-    if ( defined $parameters ) {
-        $string =
-            'Failed to find '
-          . $parameters->{using} . ' of "'
-          . $parameters->{value};
-    }
-    else {
-        $string = $response->{error}->{message};
-    }
-    my $self = bless {
+    my $string = $response->{error}->{message};
+    my $self   = bless {
         string     => $string,
         response   => $response,
         parameters => $parameters,
@@ -35,7 +26,7 @@ Firefox::Marionette::Exception::StaleElement - Represents a 'stale element refer
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -78,7 +69,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
