@@ -3,7 +3,10 @@ package Firefox::Marionette::Proxy;
 use strict;
 use warnings;
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
+
+sub DEFAULT_SOCKS_VERSION { return 5 }
+sub DEFAULT_SQUID_PORT    { return 3128 }
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -14,15 +17,37 @@ sub new {
         $parameters{type} = 'manual';
         my $host = "$parameters{host}";
         if ( $host !~ /:\d+$/smx ) {
-            $host .= q[:80];
+            $host .= q[:] . DEFAULT_SQUID_PORT();
         }
         $parameters{http}  = $host;
         $parameters{https} = $host;
     }
+    elsif ( $parameters{tls} ) {
+        $parameters{pac} =
+          $class->get_inline_pac( 'https://' . $parameters{tls} );
+    }
+    else {
+        if ( $parameters{socks} ) {
+            $parameters{type} = 'manual';
+            if ( !defined $parameters{socks_version} ) {
+                $parameters{socks_version} = DEFAULT_SOCKS_VERSION();
+            }
+        }
+    }
     my $element = bless {%parameters}, $class;
     return $element;
 }
 
+sub get_inline_pac {
+    my ( $class, @proxies ) = @_;
+    my $body = join q[;], map {
+        ( uc $_->scheme() eq 'HTTP' ? 'PROXY' : uc $_->scheme() ) . q[ ]
+          . $_->host_port()
+      }
+      map { URI->new($_) } @proxies;
+    return qq[data:text/plain,function FindProxyForURL(){return "$body"}];
+}
+
 sub type {
     my ($self) = @_;
     return $self->{type};
@@ -82,7 +107,7 @@ Firefox::Marionette::Proxy - Represents a Proxy used by Firefox Capabilities usi
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -100,10 +125,25 @@ Version 1.35
     my $proxy = Firefox::Marionette::Proxy->new( host => 'squid.example.com:3128' );
     my $firefox = Firefox::Marionette->new( capabilities => Firefox::Marionette::Capabilities->new( proxy => $proxy ) );
 
+    # OR
+
+    my $proxy = Firefox::Marionette::Proxy->new( tls => "squid.example.org:443" );
+    my $firefox = Firefox::Marionette->new(capabilities => Firefox::Marionette::Capabilities->new(proxy => $proxy));
+
 =head1 DESCRIPTION
 
 This module handles the implementation of a Proxy in Firefox Capabilities using the Marionette protocol
 
+=head1 CONSTANTS
+
+=head2 DEFAULT_SOCKS_VERSION
+
+returns the default SOCKS version which is 5.
+
+=head2 DEFAULT_SQUID_PORT
+
+returns the L<default port that Squid listens on (3128)|http://www.squid-cache.org/Doc/config/http_port/>
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -116,7 +156,7 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =item * pac - defines the L<URI|URI> for a proxy auto-config file if the L<type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
 
-=item * host - defines the host for FTP, HTTP, and HTTPS traffic and sets the L<type|Firefox::Marionette::Proxy#type> to 'manual'.
+=item * host - defines the host for FTP, HTTP, and HTTPS traffic and sets the L<type|Firefox::Marionette::Proxy#type> to 'manual'.  If the port is not specified it defaults to L<DEFAULT_SQUID_PORT|/DEFAULT_SQUID_PORT>, which is 3128.
 
 =item * http - defines the proxy host for HTTP traffic when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.
 
@@ -128,10 +168,16 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =item * socks_version - defines the SOCKS proxy version when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.  It must be any integer between 0 and 255 inclusive, but it defaults to '5'.
 
+=item * tls - defines a L<pac|Firefox::Marionette::Proxy#type> function pointing to a TLS secured proxy for FTP, HTTP, and HTTPS traffic.  This was derived from L<bug 378637|https://bugzilla.mozilla.org/show_bug.cgi?id=378637>
+
 =back
 
 This method returns a new L<proxy|Firefox::Marionette::Proxy> object.
  
+=head2 get_inline_pac
+
+returns a L<proxy pac|https://developer.mozilla.org/en-US/docs/Web/HTTP/Proxy_servers_and_tunneling/Proxy_Auto-Configuration_PAC_file> file for the parameters supplied to this function.  This is only intended for internal use.
+
 =head2 type
 
 returns the type of proxy configuration.  Must be one of 'pac', 'direct', 'autodetect', 'system', or 'manual'.
@@ -154,12 +200,32 @@ returns a list of the addresses for which the proxy should be bypassed when the
 
 =head2 socks
 
-returns the proxy host for a SOCKS proxy traffic when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.
+returns the proxy host for a L<SOCKS|https://en.wikipedia.org/wiki/SOCKS> proxy traffic when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.
 
 =head2 socks_version
 
 returns the SOCKS proxy version when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.
 
+=head1 SETTING UP SOCKS SERVERS USING SSH
+
+You can setup a simple SOCKS proxy with L<ssh|https://man.openbsd.org/ssh>, using the L<-D option|https://man.openbsd.org/ssh#D>. If you setup such a server with the following command
+
+  ssh -ND localhost:8080 user@Remote.Proxy.Server
+
+and then connect to it like so;
+
+  my $firefox = Firefox::Marionette->new(
+                  proxy => Firefox::Marionette::Proxy->new(socks => 'localhost:8080')
+                     )->go('https://Target.Web.Site');
+
+the following network diagram describes what will happen
+
+     ------------          ----------         ----------
+     | Firefox  |  SSH     | Remote |  HTTPS  | Target |
+     | & Perl   |--------->| Proxy  |-------->| Web    |
+     | run here |          | Server |         | Site   |
+     ------------          ----------         ----------
+
 =head1 DIAGNOSTICS
 
 None.
@@ -186,7 +252,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
