@@ -2,31 +2,12 @@ package Firefox::Marionette::ShadowRoot;
 
 use strict;
 use warnings;
+use parent qw(Firefox::Marionette::LocalObject);
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub IDENTIFIER { return 'shadow-6066-11e4-a52e-4f735466cecf' }
 
-sub new {
-    my ( $class, $browser, %parameters ) = @_;
-    my $shadow_root = bless {
-        browser => $browser,
-        %parameters
-    }, $class;
-    return $shadow_root;
-}
-
-sub TO_JSON {
-    my ($self) = @_;
-    my $json = { IDENTIFIER() => $self->uuid() };
-    return $json;
-}
-
-sub uuid {
-    my ($self) = @_;
-    return $self->{ IDENTIFIER() };
-}
-
 1;    # Magic true value required at end of module
 __END__
 
@@ -36,7 +17,7 @@ Firefox::Marionette::ShadowRoot - Represents a Firefox shadow root retrieved usi
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -55,12 +36,14 @@ Version 1.35
 
 This module handles the implementation of a Firefox Shadow Root using the Marionette protocol
 
-=head1 SUBROUTINES/METHODS
+=head1 CONSTANTS
 
 =head2 IDENTIFIER
 
 returns the L<shadow root identifier|https://www.w3.org/TR/webdriver/#shadow-root>
 
+=head1 SUBROUTINES/METHODS
+
 =head2 new
 
 returns a new L<shadow root|Firefox::Marionette::ShadowRoot>.
@@ -95,7 +78,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
