@@ -4,14 +4,14 @@ use warnings;
 use strict;
 use English qw( -no_match_vars );
 use Waterfox::Marionette::Profile();
-use base qw(Firefox::Marionette);
+use parent qw(Firefox::Marionette);
 Firefox::Marionette->import(qw(:all));
 
 our @EXPORT_OK =
   qw(BY_XPATH BY_ID BY_NAME BY_TAG BY_CLASS BY_SELECTOR BY_LINK BY_PARTIAL);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-our $VERSION = '1.35';
+our $VERSION = '1.62';
 
 sub default_binary_name {
     return 'waterfox';
@@ -54,7 +54,7 @@ Waterfox::Marionette - Automate the Waterfox browser with the Marionette protoco
 
 =head1 VERSION
 
-Version 1.35
+Version 1.62
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ Thanks for the L<Waterfox browser|https://www.waterfox.net/>
  
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
